#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from babel import UnknownLocaleError
from babel.core import Locale
from babel.dates import format_date
from zope.interface import Interface

from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.shared.news import IWfNewsEvent
from pyams_default_theme.shared.common.interfaces import ICustomContentSpecificitiesRenderer
from pyams_i18n.interfaces import INegotiator
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.registry import get_utility
from pyams_viewlet.viewlet import ViewContentProvider
from pyams_workflow.interfaces import IWorkflowPublicationInfo


@adapter_config(context=(IWfNewsEvent, IONFBaseLayer, Interface), provides=ICustomContentSpecificitiesRenderer)
@template_config(template='templates/specificities.pt', layer=IONFBaseLayer)
class NewsEventSpecificitiesRenderer(ViewContentProvider):
    """News event specificities renderer"""

    @property
    def publication_date(self):
        info = IWorkflowPublicationInfo(self.context, None)
        if info is not None:
            try:
                locale = Locale(self.request.locale_name)
            except UnknownLocaleError:
                negotiator = get_utility(INegotiator)
                locale = Locale(negotiator.server_language)
            return format_date(info.visible_publication_date, format='long', locale=locale)
